@@ -70,7 +70,6 @@ typedef struct _LoadContext {
     SeahorseSSHSource *ssrc;
     GHashTable *loaded;
     GHashTable *checks;
-    guint mode;
     GQuark match;
     gboolean matched;
     gchar *pubfile;
@@ -143,8 +142,7 @@ key_changed (SeahorseKey *skey, SeahorseKeyChange change, SeahorseKeySource *sks
      * need to reload in that case */
     
     if (change != SKEY_CHANGE_ALL)
-        seahorse_key_source_load_async (sksrc, SKSRC_LOAD_KEY, 
-                                        seahorse_key_get_keyid (skey), NULL);
+        seahorse_key_source_load_async (sksrc, seahorse_key_get_keyid (skey));
 }
 
 static void
@@ -181,7 +179,7 @@ scheduled_refresh (SeahorseSSHSource *ssrc)
 {
     DEBUG_REFRESH ("scheduled refresh event ocurring now\n");
     cancel_scheduled_refresh (ssrc);
-    seahorse_key_source_load_async (SEAHORSE_KEY_SOURCE (ssrc), SKSRC_LOAD_ALL, 0, NULL);
+    seahorse_key_source_load_async (SEAHORSE_KEY_SOURCE (ssrc), 0);
     return FALSE; /* don't run again */    
 }
 
@@ -294,38 +292,23 @@ ssh_key_from_data (SeahorseSSHSource *ssrc, LoadContext *ctx,
                                           GUINT_TO_POINTER (TRUE));
     }
 
-    switch(ctx->mode) {
-
-    /* Lookin for a specific key */
-    case SKSRC_LOAD_KEY:
-        if (ctx->match != keyid) {
+    /* Looking for a specific key */
+    if (ctx->match) {
+        if(ctx->match != keyid) {
             seahorse_ssh_key_data_free (keydata);
             return NULL;
         }
         ctx->matched = TRUE;
-        /* Fall through */
-        
-    /* Refresh any keys, add any new ones */
-    case SKSRC_LOAD_NEW:
-        /* If we already have this key then just transfer ownership of keydata */
-        if (prev) {
-            g_object_set (prev, "key-data", keydata, NULL);
-            return SEAHORSE_SSH_KEY (prev);
-        }
-        break;
-        
-    /* Full reload */
-    case SKSRC_LOAD_ALL:
-        if (prev) 
-            seahorse_context_remove_key (SCTX_APP (), prev);
-        break;
-        
-    default:
-        break;
     }
-    
-    g_assert (keydata);
+        
+    /* If we already have this key then just transfer ownership of keydata */
+    if (prev) {
+        g_object_set (prev, "key-data", keydata, NULL);
+        return SEAHORSE_SSH_KEY (prev);
+    }
 
+    /* Create a new key */        
+    g_assert (keydata);
     skey = seahorse_ssh_key_new (sksrc, keydata);
             
     /* We listen in to get notified of changes on this key */
@@ -452,6 +435,7 @@ write_gpgme_data (gpgme_data_t data, const gchar *str)
 {
     int len = strlen (str);
     int r = gpgme_data_write (data, str, len);
+
     return len == r;
 }
 
@@ -460,8 +444,7 @@ write_gpgme_data (gpgme_data_t data, const gchar *str)
  */
 
 static SeahorseOperation*
-seahorse_ssh_source_load (SeahorseKeySource *sksrc, SeahorseKeySourceLoad mode,
-                          GQuark keymatch, const gchar *match)
+seahorse_ssh_source_load (SeahorseKeySource *sksrc, GQuark keymatch)
 {
     SeahorseSSHSource *ssrc;
     GError *err = NULL;
@@ -485,14 +468,13 @@ seahorse_ssh_source_load (SeahorseKeySource *sksrc, SeahorseKeySourceLoad mode,
     memset (&ctx, 0, sizeof (ctx));
     ctx.match = keymatch;
     ctx.matched = FALSE;
-    ctx.mode = mode;
     ctx.ssrc = ssrc;
     
     /* Since we can find duplicate keys, limit them with this hash */
     ctx.loaded = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, NULL);
     
     /* Keys that currently exist, so we can remove any that disappeared */
-    if (mode == SKSRC_LOAD_NEW)
+    if (!keymatch)
         ctx.checks = load_present_keys (sksrc);
 
     /* For each private key file */
@@ -518,7 +500,8 @@ seahorse_ssh_source_load (SeahorseKeySource *sksrc, SeahorseKeySourceLoad mode,
         
         g_free (ctx.privfile);
         g_free (ctx.pubfile);
-            
+        ctx.privfile = ctx.pubfile = NULL;
+
         if (ctx.matched)
             break;
     }
@@ -540,6 +523,7 @@ seahorse_ssh_source_load (SeahorseKeySource *sksrc, SeahorseKeySourceLoad mode,
         }
         
         g_free (ctx.pubfile);
+		ctx.pubfile = NULL;
     }
     
     /* Load the other keys file */
@@ -556,6 +540,7 @@ seahorse_ssh_source_load (SeahorseKeySource *sksrc, SeahorseKeySourceLoad mode,
         }
         
         g_free (ctx.pubfile);
+		ctx.pubfile = NULL;
     }
 
     /* Clean up and done */
@@ -612,7 +597,7 @@ seahorse_ssh_source_export (SeahorseKeySource *sksrc, GList *keys,
 {
     SeahorseSSHKeyData *keydata;
     gchar *results = NULL;
-    gchar *prefix = NULL;
+    gchar *raw = NULL;
     GError *error = NULL;
     SeahorseKey *skey;
     GList *l;
@@ -625,7 +610,7 @@ seahorse_ssh_source_export (SeahorseKeySource *sksrc, GList *keys,
         g_assert (SEAHORSE_IS_SSH_KEY (skey));
         
         results = NULL;
-        prefix = NULL;
+        raw = NULL;
         
         keydata = NULL;
         g_object_get (skey, "key-data", &keydata, NULL);
@@ -634,17 +619,20 @@ seahorse_ssh_source_export (SeahorseKeySource *sksrc, GList *keys,
         /* Complete key means the private key */
         if (complete && keydata->privfile) {
             
-            /* Add the seahorse specific prefix */
-            prefix = g_strdup_printf ("%s %s\n", SSH_KEY_SECRET_SIG, keydata->comment ? keydata->comment : "");
-            
             /* And then the data itself */
-            if (!g_file_get_contents (keydata->privfile, &results, NULL, &error))
-                results = NULL;
+            if (!g_file_get_contents (keydata->privfile, &raw, NULL, &error)) {
+                raw = results = NULL;
+            } else {
+                /* Add the seahorse specific prefix */
+                results = g_strdup_printf ("%s %s\n%s\n", SSH_KEY_SECRET_SIG, 
+                                           keydata->comment ? keydata->comment : "",
+                                           raw);
+            }
            
         /* Public key. We should already have the data loaded */
         } else if (keydata->pubfile) { 
             g_assert (keydata->rawdata);
-            results = g_strdup (keydata->rawdata);
+            results = g_strdup_printf ("%s\n", keydata->rawdata);
             
         /* Public key without identity.pub. Export it. */
         } else if (!keydata->pubfile) {
@@ -659,15 +647,15 @@ seahorse_ssh_source_export (SeahorseKeySource *sksrc, GList *keys,
         if (results) {
             
             /* Write the data out */
-            if ((prefix && !write_gpgme_data (data, prefix)) || 
-                !write_gpgme_data (data, results)) {
+            if (write_gpgme_data (data, results) == FALSE) {
                 g_set_error (&error, G_FILE_ERROR, g_file_error_from_errno (errno),
                              strerror (errno));
             }
             
             g_free (results);
-            g_free (prefix);
         }
+
+        g_free (raw);
         
         if (error != NULL)
             break;
@@ -755,7 +743,7 @@ seahorse_ssh_source_get_property (GObject *object, guint prop_id, GValue *value,
         g_value_set_uint (value, SKEY_SSH);
         break;
     case PROP_KEY_DESC:
-        g_value_set_string (value, _("SSH Key"));
+        g_value_set_string (value, _("Secure Shell Key"));
         break;
     case PROP_LOCATION:
         g_value_set_uint (value, SKEY_LOC_LOCAL);
@@ -905,8 +893,7 @@ seahorse_ssh_source_key_for_filename (SeahorseSSHSource *ssrc, const gchar *priv
         
         /* Force loading of all new keys */
         if (!i) {
-            seahorse_key_source_load_sync (SEAHORSE_KEY_SOURCE (ssrc), 
-                                           SKSRC_LOAD_NEW, 0, NULL);
+            seahorse_key_source_load_sync (SEAHORSE_KEY_SOURCE (ssrc), 0);
         }
     }
     
